@@ -40,6 +40,10 @@
 #include <lcms.h>
 #endif
 
+#ifdef HAVE_EXEMPI
+#include <exempi/xmp.h>
+#endif
+
 G_BEGIN_DECLS
 
 #ifndef __EOG_IMAGE_DECLR__
@@ -59,12 +63,14 @@ typedef struct _EogImagePrivate EogImagePrivate;
 typedef enum {
 	EOG_IMAGE_DATA_IMAGE     = 1 << 0,
 	EOG_IMAGE_DATA_DIMENSION = 1 << 1,
-	EOG_IMAGE_DATA_EXIF      = 1 << 2
+	EOG_IMAGE_DATA_EXIF      = 1 << 2,
+	EOG_IMAGE_DATA_XMP       = 1 << 3
 } EogImageData;
 
 #define EOG_IMAGE_DATA_ALL  (EOG_IMAGE_DATA_IMAGE |     \
 			     EOG_IMAGE_DATA_DIMENSION | \
-			     EOG_IMAGE_DATA_EXIF)
+			     EOG_IMAGE_DATA_EXIF |      \
+			     EOG_IMAGE_DATA_XMP)
 
 typedef enum {
 	EOG_IMAGE_ERROR_SAVE_NOT_LOCAL,
@@ -82,6 +88,7 @@ typedef enum {
 	EOG_IMAGE_STATUS_UNKNOWN,
 	EOG_IMAGE_STATUS_LOADING,
 	EOG_IMAGE_STATUS_LOADED,
+	EOG_IMAGE_STATUS_SAVING,
 	EOG_IMAGE_STATUS_FAILED
 } EogImageStatus;
 
@@ -106,7 +113,7 @@ struct _EogImageClass {
 				    gfloat    progress);
 };
 
-GType	          eog_image_get_type	             (void);
+GType	          eog_image_get_type	             (void) G_GNUC_CONST;
 
 GQuark            eog_image_error_quark              (void);
 
@@ -115,14 +122,14 @@ EogImage         *eog_image_new                      (const char *txt_uri);
 EogImage         *eog_image_new_uri                  (GnomeVFSURI *uri);
 
 gboolean          eog_image_load                     (EogImage   *img, 
-					              guint       data2read,
+					              EogImageData data2read,
 					              EogJob     *job, 
 					              GError    **error);
 
 void              eog_image_cancel_load              (EogImage   *img);
 
 gboolean          eog_image_has_data                 (EogImage   *img, 
-					              guint       data);
+					              EogImageData data);
 
 void              eog_image_data_ref                 (EogImage   *img);
 
@@ -160,10 +167,19 @@ const gchar      *eog_image_get_collate_key          (EogImage   *img);
 
 gpointer          eog_image_get_exif_info            (EogImage   *img);
 
+gpointer          eog_image_get_xmp_info             (EogImage   *img);
+
 GnomeVFSURI*      eog_image_get_uri                  (EogImage   *img);
 
 gchar*            eog_image_get_uri_for_display      (EogImage   *img);
 
+EogImageStatus    eog_image_get_status               (EogImage   *img);
+
+void              eog_image_restore_status           (EogImage   *img);
+
+void              eog_image_set_is_monitored         (EogImage   *img,
+						      gboolean    is_monitored);
+
 void              eog_image_transform                (EogImage   *img, 
 						      EogTransform *trans,
 						      EogJob     *job);
